/**
 ********************************************************************************
 * @file    ads131_reg_defs.h
 * @author  A. Guzman
 * @date    July 1, 2025
 * @brief   Register Definitions for ADS131M0x
 ********************************************************************************
 */

#ifndef REGDEFS_H_
#define REGDEFS_H_

//**** INCLUDES ****//
#include <stdint.h>
#include <stdbool.h>

/************************************
 * SPI command opcodes
 ************************************/
#define OPCODE_NULL                             ((uint16_t) 0x0000)
#define OPCODE_RESET                            ((uint16_t) 0x0011)
#define OPCODE_RREG                             ((uint16_t) 0xA000)
#define OPCODE_WREG                             ((uint16_t) 0x6000)
#define OPCODE_STANDBY                          ((uint16_t) 0x0022)
#define OPCODE_WAKEUP                           ((uint16_t) 0x0033)
#define OPCODE_LOCK                             ((uint16_t) 0x0555)
#define OPCODE_UNLOCK                           ((uint16_t) 0x0655)

/************************************
 * Register Map
 ************************************/

/**** Device Settings and Indicators (Read-Only Registers) ****/
#define ADS131M0x_ID                0x00
#define ADS131M0x_STATUS            0x01

/**** Global Settings Across Channels ****/
#define ADS131M0x_MODE              0x02
#define ADS131M0x_CLOCK             0x03
#define ADS131M0x_GAIN              0x04 
#define ADS131M0x_CFG               0x06
#define ADS131M0x_THRSHLD_MSB       0x07
#define ADS131M0x_THRSHLD_LSB       0x08

/**** Channel-Specific Settings ****/
#define ADS131M0x_CH0_CFG           0x09
#define ADS131M0x_CH0_OCAL_MSB      0x0A
#define ADS131M0x_CH0_OCAL_LSB      0x0B
#define ADS131M0x_CH0_GCAL_MSB      0x0C
#define ADS131M0x_CH0_GCAL_LSB      0x0D

#define ADS131M0x_CH1_CFG           0x0E
#define ADS131M0x_CH1_OCAL_MSB      0x0F
#define ADS131M0x_CH1_OCAL_LSB      0x10
#define ADS131M0x_CH1_GCAL_MSB      0x11
#define ADS131M0x_CH1_GCAL_LSB      0x12

#define ADS131M0x_CH2_CFG           0x13
#define ADS131M0x_CH2_OCAL_MSB      0x14
#define ADS131M0x_CH2_OCAL_LSB      0x15
#define ADS131M0x_CH2_GCAL_MSB      0x16
#define ADS131M0x_CH2_GCAL_LSB      0x17

#define ADS131M0x_CH3_CFG           0x18
#define ADS131M0x_CH3_OCAL_MSB      0x19
#define ADS131M0x_CH3_OCAL_LSB      0x1A
#define ADS131M0x_CH3_GCAL_MSB      0x1B
#define ADS131M0x_CH3_GCAL_LSB      0x1C

/**** Register Map CRC and Reserved Registers ****/
#define ADS131M0x_REGMAP_CRC        0x3E
#define ADS131M0x_RESERVED          0x3F


/************************************
 * TYPEDEFS
 ************************************/
typedef enum {
  ADS131M0x_OK = 0x00,
  ADS131M0x_ERROR = 0x01,
  ADS131M0x_BUSY = 0x02,
  ADS131M0x_TIMEOUT = 0x03,
} ADS131M0x_StatusTypeDef;

////////////////////////////////REGISTER ACCESS FUNCTIONS//////////////////////

/**** ID Register Masks ****/
#define ADS131M0x_ID_CHANCNT_MASK 0xF0FF //always reads 0x24


/**** STATUS Register Masks****/

#define ADS131M0x_STATUS_LOCK_MASK 0x7FFF
typedef enum {
  ADS131M0x_STATUS_LOCK_UNLOCKED = 0 << 15,
  ADS131M0x_STATUS_LOCK_LOCKED = 1 << 15
} ADS131M0x_STATUS_LOCK_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_STATUS_LOCK(void *handle, ADS131M0x_STATUS_LOCK_t *stat);

#define ADS131M0x_STATUS_F_RESYNC_MASK 0xBFFF
typedef enum {
  ADS131M0x_STATUS_F_RESYNC_NO_RESYNC = 0 << 14,
  ADS131M0x_STATUS_F_RESYNC_RESYNC = 1 << 14
} ADS131M0x_STATUS_F_RESYNC_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_STATUS_F_RESYNC(void *handle, ADS131M0x_STATUS_F_RESYNC_t *stat);

#define ADS131M0x_STATUS_REG_MAP_MASK 0xDFFF
typedef enum {
  ADS131M0x_STATUS_REG_MAP_NO_CHANGE_CRC = 0 << 13,
  ADS131M0x_STATUS_REG_MAP_CHANGED_CRC = 1 << 13
} ADS131M0x_STATUS_REG_MAP_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_STATUS_REG_MAP(void *handle, ADS131M0x_STATUS_REG_MAP_t *stat);

#define ADS131M0x_STATUS_CRC_ERR_MASK 0xEFFF
typedef enum {
  ADS131M0x_STATUS_CRC_ERR_NO_CRC_ERROR = 0 << 12,
  ADS131M0x_STATUS_CRC_ERROR_INPUT_CRC_ERROR = 1 << 12
} ADS131M0x_STATUS_CRC_ERR_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_STATUS_CRC_ERR(void *handle, ADS131M0x_STATUS_CRC_ERR_t *stat);

#define ADS131M0x_STATUS_CRC_TYPE_MASK 0xF7FF
typedef enum {
  ADS131M0x_STATUS_CRC_TYPE_CCITT = 0 << 11,
  ADS131M0x_STATUS_CRC_TYPE_ANSI = 1 << 11
} ADS131M0x_STATUS_CRC_TYPE_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_STATUS_CRC_TYPE(void *handle, ADS131M0x_STATUS_CRC_TYPE_t *stat);

#define ADS131M0x_STATUS_RESET_MASK 0xFBFF
typedef enum {
  ADS131M0x_STATUS_RESET_NO_RESET = 0 << 10,
  ADS131M0x_STATUS_RESET_OCCURED = 1 << 10
} ADS131M0x_STATUS_RESET_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_STATUS_RESET(void *handle, ADS131M0x_STATUS_RESET_t *stat);

#define ADS131M0x_STATUS_WLENGTH_MASK 0xFCFF
typedef enum {
  ADS131M0x_STATUS_WLENGTH_16BIT = 0 << 8,
  ADS131M0x_STATUS_WLENGTH_24BIT = 1 << 8,
  ADS131M0x_STATUS_WLENGTH_32BIT_ZERO_PADDING = 2 << 8,
  ADS131M0x_STATUS_WLENGTH_32BIT_SIGN_EXT = 3 << 8
} ADS131M0x_STATUS_WLENGTH_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_STATUS_WLENGTH(void *handle, ADS131M0x_STATUS_WLENGTH_t *stat);

#define ADS131M0x_STATUS_DRDYx_MASK 0xFFFE
typedef enum {
  ADS131M0x_STATUS_DRDYx_NO_NEW_DATA = 0,
  ADS131M0x_STATUS_DRDYx_NEW_DATA = 1
} ADS131M0x_STATUS_DRDYx_t; //Handle bit shifting in function
ADS131M0x_StatusTypeDef ADS131M0x_Get_STATUS_DRDYx(void *handle, uint8_t bit_pos, ADS131M0x_STATUS_DRDYx_t *stat);


//**** MODE Register Masks ****/

#define ADS131M0x_MODE_REG_CRC_EN_MASK 0xDFFF
typedef enum {
  ADS131M0x_MODE_REG_CRC_EN_DISABLED = 0,
  ADS131M0x_MODE_REG_CRC_EN_ENABLED = 1 << 13
} ADS131M0x_MODE_REG_CRC_EN_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_MODE_REG_CRC_EN(void *handle, ADS131M0x_MODE_REG_CRC_EN_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_MODE_REG_CRC_EN(void *handle, ADS131M0x_MODE_REG_CRC_EN_t stat);

#define ADS131M0x_MODE_RX_CRC_EN_MASK 0xEFFF
typedef enum {
  ADS131M0x_MODE_RX_CRC_EN_DISABLED = 0,
  ADS131M0x_MODE_RX_CRC_EN_ENABLED = 1 << 12
} ADS131M0x_MODE_RX_CRC_EN_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_MODE_RX_CRC_EN(void *handle, ADS131M0x_MODE_RX_CRC_EN_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_MODE_RX_CRC_EN(void *handle, ADS131M0x_MODE_RX_CRC_EN_t stat);

#define ADS131M0x_MODE_CRC_TYPE_MASK 0xF7FF
typedef enum {
  ADS131M0x_MODE_CRC_TYPE_16BIT_CCITT = 0,
  ADS131M0x_MODE_CRC_TYPE_16BIT_ANSI = 1 << 11
} ADS131M0x_MODE_CRC_TYPE_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_MODE_CRC_TYPE(void *handle, ADS131M0x_MODE_CRC_TYPE_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_MODE_CRC_TYPE(void *handle, ADS131M0x_MODE_CRC_TYPE_t stat);

#define ADS131M0x_MODE_RESET_MASK 0xFBFF
typedef enum {
  ADS131M0x_MODE_RESET_NO_RESET = 0,
  ADS131M0x_MODE_RESET_CLEAR_BIT = 0,
  ADS131M0x_MODE_RESET_OCCURED = 1 << 10
} ADS131M0x_MODE_RESET_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_MODE_RESET(void *handle, ADS131M0x_MODE_RESET_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_MODE_RESET(void *handle, ADS131M0x_MODE_RESET_t stat);

#define ADS131M0x_MODE_WLENGTH_MASK 0xFCFF
typedef enum {
  ADS131M0x_MODE_WLENGTH_16BIT = 0,
  ADS131M0x_MODE_WLENGTH_24BIT = 1 << 8,
  ADS131M0x_MODE_WLENGTH_32BIT_LSB_ZEROES = 2 << 8,
  ADS131M0x_MODE_WLENGTH_32BIT_MSB_SIGN_EXT = 3 << 8
} ADS131M0x_MODE_WLENGTH_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_MODE_WLENGTH(void *handle, ADS131M0x_MODE_WLENGTH_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_MODE_WLENGTH(void *handle, ADS131M0x_MODE_WLENGTH_t stat);

#define ADS131M0x_MODE_TIMEOUT_MASK 0xFFEF
typedef enum {
  ADS131M0x_MODE_TIMEOUT_DISABLED = 0,
  ADS131M0x_MODE_TIMEOUT_ENABLED = 1 << 4
} ADS131M0x_MODE_TIMEOUT_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_MODE_TIMEOUT(void *handle, ADS131M0x_MODE_TIMEOUT_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_MODE_TIMEOUT(void *handle, ADS131M0x_MODE_TIMEOUT_t stat);

#define ADS131M0x_MODE_DRDY_SEL_MASK 0xFFF3
typedef enum {
  ADS131M0x_MODE_DRDY_SEL_MOST_LAGGING = 0,
  ADS131M0x_MODE_DRDY_SEL_LOGIC_OR = 1 << 2,
  ADS131M0x_MODE_DRDY_SEL_MOST_LEADING = 2 << 2
  // ADS131M0x_MODE_DRDY_SEL_MOST_LEADING = 3 << 2 //Additional option, not needed
} ADS131M0x_MODE_DRDY_SEL_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_MODE_DRDY_SEL(void *handle, ADS131M0x_MODE_DRDY_SEL_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_MODE_DRDY_SEL(void *handle, ADS131M0x_MODE_DRDY_SEL_t stat);

#define ADS131M0x_MODE_DRDY_HiZ_MASK 0xFFFD
typedef enum {
  ADS131M0x_MODE_DRDY_HiZ_LOGIC_HIGH = 0,
  ADS131M0x_MODE_DRDY_HiZ_HIGH_IMPEDANCE = 1 << 1
} ADS131M0x_MODE_DRDY_HiZ_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_MODE_DRDY_HiZ(void *handle, ADS131M0x_MODE_DRDY_HiZ_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_MODE_DRDY_HiZ(void *handle, ADS131M0x_MODE_DRDY_HiZ_t stat);

#define ADS131M0x_MODE_DRDY_FMT_MASK 0xFFFE
typedef enum {
  ADS131M0x_MODE_DRDY_FMT_LOGIC_LOW = 0,
  ADS131M0x_MODE_DRDY_FMT_LOW_PULSE_FIXED = 1
} ADS131M0x_MODE_DRDY_FMT_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_MODE_DRDY_FMT(void *handle, ADS131M0x_MODE_DRDY_FMT_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_MODE_DRDY_FMT(void *handle, ADS131M0x_MODE_DRDY_FMT_t stat);

/**** CLOCK Register Masks ****/

#define ADS131M0x_CLOCK_CH3_EN_MASK 0xF7FF
typedef enum {
  ADS131M0x_CLOCK_CH3_EN_DISABLED = 0 << 11,
  ADS131M0x_CLOCK_CH3_EN_ENABLED = 1 << 11
} ADS131M0x_CLOCK_CH3_EN_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CLOCK_CH3_EN(void *handle, ADS131M0x_CLOCK_CH3_EN_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CLOCK_CH3_EN(void *handle, ADS131M0x_CLOCK_CH3_EN_t stat);

#define ADS131M0x_CLOCK_CH2_EN_MASK 0xFBFF
typedef enum {
  ADS131M0x_CLOCK_CH2_EN_DISABLED = 0,
  ADS131M0x_CLOCK_CH2_EN_ENABLED = 1 << 10
} ADS131M0x_CLOCK_CH2_EN_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CLOCK_CH2_EN(void *handle, ADS131M0x_CLOCK_CH2_EN_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CLOCK_CH2_EN(void *handle, ADS131M0x_CLOCK_CH2_EN_t stat);

#define ADS131M0x_CLOCK_CH1_EN_MASK 0xFDFF
typedef enum {
  ADS131M0x_CLOCK_CH1_EN_DISABLED = 0 << 9,
  ADS131M0x_CLOCK_CH1_EN_ENABLED = 1 << 9
} ADS131M0x_CLOCK_CH1_EN_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CLOCK_CH1_EN(void *handle, ADS131M0x_CLOCK_CH1_EN_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CLOCK_CH1_EN(void *handle, ADS131M0x_CLOCK_CH1_EN_t stat);

#define ADS131M0x_CLOCK_CH0_EN_MASK 0xFEFF
typedef enum {
  ADS131M0x_CLOCK_CH0_EN_DISABLED = 0,
  ADS131M0x_CLOCK_CH0_EN_ENABLED = 1 << 8
} ADS131M0x_CLOCK_CH0_EN_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CLOCK_CH0_EN(void *handle, ADS131M0x_CLOCK_CH0_EN_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CLOCK_CH0_EN(void *handle, ADS131M0x_CLOCK_CH0_EN_t stat);

#define ADS131M0x_CLOCK_TBM_MASK 0xFF1F
typedef enum {
  ADS131M0x_CLOCK_TBM_OSR_SET_BY_BITS = 0,
  ADS131M0x_CLOCK_TBM_OSR_64 = 1 << 5
} ADS131M0x_CLOCK_TBM_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CLOCK_TBM(void *handle, ADS131M0x_CLOCK_TBM_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CLOCK_TBM(void *handle, ADS131M0x_CLOCK_TBM_t stat);

#define ADS131M0x_CLOCK_OSR_MASK 0xFF23
typedef enum {
  ADS131M0x_CLOCK_OSR_128 = 0,
  ADS131M0x_CLOCK_OSR_256 = 1 << 2,
  ADS131M0x_CLOCK_OSR_512 = 2 << 2,
  ADS131M0x_CLOCK_OSR_1024 = 3 << 2,
  ADS131M0x_CLOCK_OSR_2048 = 4 << 2,
  ADS131M0x_CLOCK_OSR_4096 = 5 << 2,
  ADS131M0x_CLOCK_OSR_8192 = 6 << 2,
  ADS131M0x_CLOCK_OSR_16256 = 7 << 2,
} ADS131M0x_CLOCK_OSR_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CLOCK_OSR(void *handle, ADS131M0x_CLOCK_OSR_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CLOCK_OSR(void *handle, ADS131M0x_CLOCK_OSR_t stat);

#define ADS131M0x_CLOCK_PWR_MASK 0xFFFC
typedef enum {
  ADS131M0x_CLOCK_PWR_VERY_LOW_POWER = 0,
  ADS131M0x_CLOCK_PWR_LOW_POWER = 1,
  ADS131M0x_CLOCK_PWR_HIGH_RES = 2,
  // ADS131M0x_CLOCK_PWR_HIGH_RES = 3 additional option, not needed
} ADS131M0x_CLOCK_PWR_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CLOCK_PWR(void *handle, ADS131M0x_CLOCK_PWR_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CLOCK_PWR(void *handle, ADS131M0x_CLOCK_PWR_t stat);

/**** GAIN Register Masks ****/

#define ADS131M0x_GAIN_PGAGAINx_MASK 0xFFF7
typedef enum {
  ADS131M0x_GAIN_PGAGAIN_1 = 0,
  ADS131M0x_GAIN_PGAGAIN_2 = 1,
  ADS131M0x_GAIN_PGAGAIN_4 = 2,
  ADS131M0x_GAIN_PGAGAIN_8 = 3,
  ADS131M0x_GAIN_PGAGAIN_16 = 4,
  ADS131M0x_GAIN_PGAGAIN_32 = 5,
  ADS131M0x_GAIN_PGAGAIN_64 = 6,
  ADS131M0x_GAIN_PGAGAIN_128 = 7
} ADS131M0x_GAIN_PGAGAIN_t; //HANDLE BIT SHIFTING IN FUNCTION
ADS131M0x_StatusTypeDef ADS131M0x_Set_GAIN_PGAGAINx(void *handle, uint8_t channel, ADS131M0x_GAIN_PGAGAIN_t stat);
ADS131M0x_StatusTypeDef ADS131M0x_Get_GAIN_PGAGAINx(void *handle, uint8_t channel, ADS131M0x_GAIN_PGAGAIN_t *stat);


/**** CFG Register Masks ****/

#define ADS131M0x_CFG_GC_DLY_MASK 0xE1FF
typedef enum {
  ADS131M0x_CFG_GC_DLY_2 = 0,
  ADS131M0x_CFG_GC_DLY_4 = 1 << 9,
  ADS131M0x_CFG_GC_DLY_8 = 2 << 9,
  ADS131M0x_CFG_GC_DLY_16 = 3 << 9,
  ADS131M0x_CFG_GC_DLY_32 = 4 << 9,
  ADS131M0x_CFG_GC_DLY_64 = 5 << 9,
  ADS131M0x_CFG_GC_DLY_128 = 6 << 9,
  ADS131M0x_CFG_GC_DLY_256 = 7 << 9,
  ADS131M0x_CFG_GC_DLY_512 = 8 << 9,
  ADS131M0x_CFG_GC_DLY_1024 = 9 << 9,
  ADS131M0x_CFG_GC_DLY_2048 = 10 << 9,
  ADS131M0x_CFG_GC_DLY_4096 = 11 << 9,
  ADS131M0x_CFG_GC_DLY_8192 = 12 << 9,
  ADS131M0x_CFG_GC_DLY_16256 = 13 << 9,
  ADS131M0x_CFG_GC_DLY_32768 = 14 << 9,
  ADS131M0x_CFG_GC_DLY_65536 = 15 << 9
} ADS131M0x_CFG_GC_DLY_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CFG_GC_DLY(void *handle, ADS131M0x_CFG_GC_DLY_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CFG_GC_DLY(void *handle, ADS131M0x_CFG_GC_DLY_t stat);

#define ADS131M0x_CFG_GC_EN_MASK 0xFEFF
typedef enum {
  ADS131M0x_CFG_GC_EN_DISABLED = 0,
  ADS131M0x_CFG_GC_EN_ENABLED = 1 << 8
} ADS131M0x_CFG_GC_EN_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CFG_GC_EN(void *handle, ADS131M0x_CFG_GC_EN_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CFG_GC_EN(void *handle, ADS131M0x_CFG_GC_EN_t stat);

#define ADS131M0x_CFG_CD_ALLCH_MASK 0xFF7F
typedef enum {
  ADS131M0x_CFG_CD_ALLCH_ANY_CHANNEL = 0,
  ADS131M0x_CFG_CD_ALLCH_ALL_CHANNELS = 1 << 7
} ADS131M0x_CFG_CD_ALLCH_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CFG_CD_ALLCH(void *handle, ADS131M0x_CFG_CD_ALLCH_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CFG_CD_ALLCH(void *handle, ADS131M0x_CFG_CD_ALLCH_t stat);

#define ADS131M0x_CFG_CD_NUM_MASK 0xFF8F
typedef enum {
  ADS131M0x_CFG_CD_NUM_1 = 0 << 4,
  ADS131M0x_CFG_CD_NUM_2 = 1 << 4,
  ADS131M0x_CFG_CD_NUM_4 = 2 << 4,
  ADS131M0x_CFG_CD_NUM_8 = 3 << 4,
  ADS131M0x_CFG_CD_NUM_16 = 4 << 4,
  ADS131M0x_CFG_CD_NUM_32 = 5 << 4,
  ADS131M0x_CFG_CD_NUM_64 = 6 << 4,
  ADS131M0x_CFG_CD_NUM_128 = 7 << 4,
} ADS131M0x_CFG_CD_NUM_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CFG_CD_NUM(void *handle, ADS131M0x_CFG_CD_NUM_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CFG_CD_NUM(void *handle, ADS131M0x_CFG_CD_NUM_t stat);

#define ADS131M0x_CFG_CD_LEN_MASK 0xFFF1
typedef enum {
  ADS131M0x_CFG_CD_LEN_128 = 0 << 1,
  ADS131M0x_CFG_CD_LEN_256 = 1 << 1,
  ADS131M0x_CFG_CD_LEN_512 = 2 << 1,
  ADS131M0x_CFG_CD_LEN_768 = 3 << 1,
  ADS131M0x_CFG_CD_LEN_1280 = 4 << 1,
  ADS131M0x_CFG_CD_LEN_1792 = 5 << 1,
  ADS131M0x_CFG_CD_LEN_2560 = 6 << 1,
  ADS131M0x_CFG_CD_LEN_3584 = 7 << 1,
} ADS131M0x_CFG_CD_LEN_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CFG_CD_LEN(void *handle, ADS131M0x_CFG_CD_LEN_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CFG_CD_LEN(void *handle, ADS131M0x_CFG_CD_LEN_t stat);

#define ADS131M0x_CFG_CD_EN_MASK 0xFFFE
typedef enum {
  ADS131M0x_CFG_CD_EN_DISABLED = 0,
  ADS131M0x_CFG_CD_EN_ENABLED = 1
} ADS131M0x_CFG_CD_EN_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CFG_CD_EN(void *handle, ADS131M0x_CFG_CD_EN_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CFG_CD_EN(void *handle, ADS131M0x_CFG_CD_EN_t stat);

/**** THRSHLD_MSB Register Masks ****/
#define ADS131M0x_THRSHLD_MSB_CD_TH_MSB_MASK 0x0000
typedef enum {
  ADS131M0x_THRSHLD_MSB_CD_TH_MSB = 0 //Current-detect mode threshold MSB
} ADS131M0x_THRSHLD_MSB_CD_TH_MSB_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_THRSHLD_MSB_CD_TH_MSB(void *handle, ADS131M0x_THRSHLD_MSB_CD_TH_MSB_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_THRSHLD_MSB_CD_TH_MSB(void *handle, ADS131M0x_THRSHLD_MSB_CD_TH_MSB_t stat);

/**** THRSHLD_LSB Register Masks ****/
#define ADS131M0x_THRSHLD_LSB_CD_TH_LSB_MASK 0x00FF
typedef enum {
  ADS131M0x_THRSHLD_LSB_CD_TH_LSB = 0 //Current-detect mode threshold LSB
} ADS131M0x_THRSHLD_LSB_CD_TH_LSB_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_THRSHLD_LSB_CD_TH_LSB(void *handle, ADS131M0x_THRSHLD_LSB_CD_TH_LSB_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_THRSHLD_LSB_CD_TH_LSB(void *handle, ADS131M0x_THRSHLD_LSB_CD_TH_LSB_t stat);

#define ADS131M0x_THRSHLD_LSB_DCBLOCK_MASK 0x00FF
typedef enum {
  ADS131M0x_THRSHLD_LSB_DCBLOCK_FILTER_DISABLED = 0,
  ADS131M0x_THRSHLD_LSB_DCBLOCK_4 = 1, // 1/4
  ADS131M0x_THRSHLD_LSB_DCBLOCK_8 = 2, // 1/8
  ADS131M0x_THRSHLD_LSB_DCBLOCK_16 = 3, // 1/16
  ADS131M0x_THRSHLD_LSB_DCBLOCK_32 = 4, // 1/32
  ADS131M0x_THRSHLD_LSB_DCBLOCK_64 = 5, // 1/64
  ADS131M0x_THRSHLD_LSB_DCBLOCK_128 = 6, // 1/128
  ADS131M0x_THRSHLD_LSB_DCBLOCK_256 = 7, // 1/256
  ADS131M0x_THRSHLD_LSB_DCBLOCK_512 = 8, // 1/512
  ADS131M0x_THRSHLD_LSB_DCBLOCK_1024 = 9, // 1/1024
  ADS131M0x_THRSHLD_LSB_DCBLOCK_2048 = 10, // 1/2048
  ADS131M0x_THRSHLD_LSB_DCBLOCK_4096 = 11, // 1/4096
  ADS131M0x_THRSHLD_LSB_DCBLOCK_8192 = 12, // 1/8192
  ADS131M0x_THRSHLD_LSB_DCBLOCK_16256 = 13, // 1/16256
  ADS131M0x_THRSHLD_LSB_DCBLOCK_32768 = 14, // 1/32768
  ADS131M0x_THRSHLD_LSB_DCBLOCK_65536 = 15 // 1/65536
} ADS131M0x_THRSHLD_LSB_DCBLOCK_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_THRSHLD_LSB_DCBLOCK(void *handle, ADS131M0x_THRSHLD_LSB_DCBLOCK_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_THRSHLD_LSB_DCBLOCK(void *handle, ADS131M0x_THRSHLD_LSB_DCBLOCK_t stat);

//**** CH0_CFG Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH0_CFG_PHASE0(void *handle, uint16_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH0_CFG_PHASE0(void *handle, uint16_t stat);

#define ADS131M0x_CH0_CFG_DCBLK0_DIS0_MASK 0xFFF3
typedef enum{
  ADS131M0x_CH0_CFG_DCBLK0_DIS0_DEFAULT = 0,
  ADS131M0x_CH0_CFG_DCBLK0_DIS0_DISABLED = 1 << 2
} ADS131M0x_CH0_CFG_DCBLK0_DIS0_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH0_CFG_DCBLK0_DIS0(void *handle, ADS131M0x_CH0_CFG_DCBLK0_DIS0_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH0_CFG_DCBLK0_DIS0(void *handle, ADS131M0x_CH0_CFG_DCBLK0_DIS0_t stat);

#define ADS131M0x_CH0_CFG_MUX0_MASK 0xFFFE
typedef enum {
  ADS131M0x_CH0_CFG_MUX0_AIN0P_AIN0N = 0,
  ADS131M0x_CH0_CFG_MUX0_INPUT_SHORTED = 1,
  ADS131M0x_CH0_CFG_MUX0_POS_DC_TEST = 2,
  ADS131M0x_CH0_CFG_MUX0_NEG_DC_TEST = 3
} ADS131M0x_CH0_CFG_MUX0_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH0_CFG_MUX0(void *handle, ADS131M0x_CH0_CFG_MUX0_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH0_CFG_MUX0(void *handle, ADS131M0x_CH0_CFG_MUX0_t stat);

//**** CH0_OCAL Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH0_OCAL(void *handle, uint32_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH0_OCAL(void *handle, uint32_t stat);
//**** CH0_GCAL Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH0_GCAL(void *handle, uint32_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH0_GCAL(void *handle, uint32_t stat);

//**** CH1_CFG Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH1_CFG_PHASE1(void *handle, uint16_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH1_CFG_PHASE1(void *handle, uint16_t stat);

#define ADS131M0x_CH1_CFG_DCBLK1_DIS1_MASK 0xFFF3
typedef enum{
  ADS131M0x_CH1_CFG_DCBLK1_DIS0_DEFAULT = 0,
  ADS131M0x_CH1_CFG_DCBLK1_DIS0_DISABLED = 1 << 2
} ADS131M0x_CH1_CFG_DCBLK1_DIS0_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH1_CFG_DCBLK1_DIS0(void *handle, ADS131M0x_CH1_CFG_DCBLK1_DIS0_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH1_CFG_DCBLK1_DIS0(void *handle, ADS131M0x_CH1_CFG_DCBLK1_DIS0_t stat);

#define ADS131M0x_CH1_CFG_MUX1_MASK 0xFFFE
typedef enum {
  ADS131M0x_CH1_CFG_MUX1_AIN1P_AIN1N = 0,
  ADS131M0x_CH1_CFG_MUX1_INPUT_SHORTED = 1,
  ADS131M0x_CH1_CFG_MUX1_POS_DC_TEST = 2,
  ADS131M0x_CH1_CFG_MUX1_NEG_DC_TEST = 3
} ADS131M0x_CH1_CFG_MUX1_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH1_CFG_MUX1(void *handle, ADS131M0x_CH1_CFG_MUX1_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH1_CFG_MUX1(void *handle, ADS131M0x_CH1_CFG_MUX1_t stat);

//**** CH1_OCAL Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH1_OCAL(void *handle, uint32_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH1_OCAL(void *handle, uint32_t stat);

//**** CH1_GCAL Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH1_GCAL(void *handle, uint32_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH1_GCAL(void *handle, uint32_t stat);

//**** CH2_CFG Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH2_CFG_PHASE2(void *handle, uint16_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH2_CFG_PHASE2(void *handle, uint16_t stat);

#define ADS131M0x_CH2_CFG_DCBLK2_DIS2_MASK 0xFFF3
typedef enum{
  ADS131M0x_CH2_CFG_DCBLK2_DIS0_DEFAULT = 0,
  ADS131M0x_CH2_CFG_DCBLK2_DIS0_DISABLED = 1 << 2
} ADS131M0x_CH2_CFG_DCBLK2_DIS0_t;

ADS131M0x_StatusTypeDef ADS131M0x_Get_CH2_CFG_DCBLK2_DIS0(void *handle, ADS131M0x_CH2_CFG_DCBLK2_DIS0_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH2_CFG_DCBLK2_DIS0(void *handle, ADS131M0x_CH2_CFG_DCBLK2_DIS0_t stat);

#define ADS131M0x_CH2_CFG_MUX2_MASK 0xFFFE
typedef enum {
  ADS131M0x_CH2_CFG_MUX2_AIN2P_AIN2N = 0,
  ADS131M0x_CH2_CFG_MUX2_INPUT_SHORTED = 1,
  ADS131M0x_CH2_CFG_MUX2_POS_DC_TEST = 2,
  ADS131M0x_CH2_CFG_MUX2_NEG_DC_TEST = 3
} ADS131M0x_CH2_CFG_MUX2_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH2_CFG_MUX2(void *handle, ADS131M0x_CH2_CFG_MUX2_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH2_CFG_MUX2(void *handle, ADS131M0x_CH2_CFG_MUX2_t stat);

// //**** CH2_OCAL Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH2_OCAL(void *handle, uint32_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH2_OCAL(void *handle, uint32_t stat);

// //**** CH2_GCAL Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH2_GCAL(void *handle, uint32_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH2_GCAL(void *handle, uint32_t stat);

//**** CH3_CFG Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH3_CFG_PHASE3(void *handle, uint16_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH3_CFG_PHASE3(void *handle, uint16_t stat);

#define ADS131M0x_CH3_CFG_DCBLK3_DIS3_MASK 0xFFF3
typedef enum{
  ADS131M0x_CH3_CFG_DCBLK3_DIS0_DEFAULT = 0,
  ADS131M0x_CH3_CFG_DCBLK3_DIS0_DISABLED = 1 << 2
} ADS131M0x_CH3_CFG_DCBLK3_DIS0_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH3_CFG_DCBLK3_DIS0(void *handle, ADS131M0x_CH3_CFG_DCBLK3_DIS0_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH3_CFG_DCBLK3_DIS0(void *handle, ADS131M0x_CH3_CFG_DCBLK3_DIS0_t stat);

#define ADS131M0x_CH3_CFG_MUX3_MASK 0xFFFE
typedef enum {
  ADS131M0x_CH3_CFG_MUX3_AIN3P_AIN3N = 0,
  ADS131M0x_CH3_CFG_MUX3_INPUT_SHORTED = 1,
  ADS131M0x_CH3_CFG_MUX3_POS_DC_TEST = 2,
  ADS131M0x_CH3_CFG_MUX3_NEG_DC_TEST = 3
} ADS131M0x_CH3_CFG_MUX3_t;
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH3_CFG_MUX3(void *handle, ADS131M0x_CH3_CFG_MUX3_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH3_CFG_MUX3(void *handle, ADS131M0x_CH3_CFG_MUX3_t stat);

//**** CH3_OCAL Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH3_OCAL(void *handle, uint32_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH3_OCAL(void *handle, uint32_t stat);

//**** CH3_GCAL Register Masks ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_CH3_GCAL(void *handle, uint32_t *stat);
ADS131M0x_StatusTypeDef ADS131M0x_Set_CH3_GCAL(void *handle, uint32_t stat);

//****REGMAP_CRC Register Mask ****/
ADS131M0x_StatusTypeDef ADS131M0x_Get_REGMAP_CRC(void *handle, uint16_t *stat);

#endif